#' usincometaxes: A package for calculating state and federal income taxes in the United States.
#'
#' The \code{usincometaxes} package is a single function packages that calculates state and federal income
#' taxes in the United State. It relies on the NBER's TAXSIM 35 tax calculator for the calculations.
#' See \url{https://taxsim.nber.org/taxsim35/} for more information on TAXSIM 35.
'_PACKAGE'
